@@ -4,16 +4,16 @@ from fastapi import APIRouter, Depends, Request
 
 from optimade.models import ErrorResponse, LinksResponse, LinksResource
 from optimade.server.config import CONFIG
-from optimade.server.entry_collections import MongoCollection, client
+from optimade.server.entry_collections import create_collection
 from optimade.server.mappers import LinksMapper
 from optimade.server.query_params import EntryListingQueryParams
 
-from .utils import get_entries
+from optimade.server.routers.utils import get_entries
 
 router = APIRouter(redirect_slashes=True)
 
-links_coll = MongoCollection(
-    collection=client[CONFIG.mongo_database][CONFIG.links_collection],
+links_coll = create_collection(
+    name=CONFIG.links_collection,
     resource_cls=LinksResource,
     resource_mapper=LinksMapper,
 )
